==> SwimmeR_0.12.0.tar.gz: SwimmeR/R/globals.R <==
utils::globalVariables(
  c(
    ".",
    "V1",
    "V2",
    "V3",
    "V4",
    "V5",
    "V6",
    "V7",
    "V8",
    "V9",
    "V10",
    "V11",
    "V12",
    "V13",
    "V14",
    "V15",
    "Event_Row_Min",
    "Grade",
    "Finals_Time",
    "School",
    "Name",
    "Prelims_Time",
    "Place",
    "Points",
    "Row_Numb",
    "Row_Numb_Adjusted",
    "relay_swimmers",
    "Event",
    "read_html",
    ":=",
    "ID",
    "Course",
    "Seed_Time",
    "Row_Min",
    "Row_Max",
    "X2",
    "X3",
    "X8",
    "X9",
    "USA_ID",
    "Birthdate",
    "ID_Numb",
    "Team",
    "Relay_Rank",
    "Row_Numb.x",
    "Row_Numb.y",
    "as_lines_list_2",
    "First",
    "Last",
    "Last_Name",
    "Finals_Time_sec",
    "New_Place",
    "Finals_Place",
    "DQ",
    "Heat",
    "Heat_Row_Min",
    "Exhibition",
    "Time",
    "Lane",
    "Time_Score_String",
    "Grade_String",
    "Name_String",
    "Row_Fill",
    "Row_Numb_2",
    "minimum_row",
    "maximum_row",
    "Colon_String",
    "old_names",
    "new_names",
    "flag",
    "split_length",
    "split_len",
    "Relay_Swimmer_1",
    "Relay_Swimmer_2",
    "Relay_Swimmer_3",
    "Relay_Swimmer_4",
    "Split_50",
    "Age",
    "Para",
    "typo",
    "replacement",
    "clean",
    "Switch",
    "avoid",
    "Place_1",
    "Min_C_Place",
    "Prelims_Place",
    "First_Name",
    "Name_2",
    "Name_3",
    "where",
    "fFactor",
    "fIncre",
    "Time_Converted_sec",
    "Time_Converted_mmss",
    "split_length_omega",
    "Reaction_Time",
    "Finals_Time_Sec",
    "Split_Total"
  )
)

==> SwimmeR_0.13.0.tar.gz: SwimmeR/R/globals.R <==
utils::globalVariables(
  c(
    ".",
    "V1",
    "V2",
    "V3",
    "V4",
    "V5",
    "V6",
    "V7",
    "V8",
    "V9",
    "V10",
    "V11",
    "V12",
    "V13",
    "V14",
    "V15",
    "Event_Row_Min",
    "Grade",
    "Finals_Time",
    "School",
    "Name",
    "Prelims_Time",
    "Place",
    "Points",
    "Row_Numb",
    "Row_Numb_Adjusted",
    "relay_swimmers",
    "Event",
    "read_html",
    ":=",
    "ID",
    "Course",
    "Seed_Time",
    "Row_Min",
    "Row_Max",
    "X2",
    "X3",
    "X8",
    "X9",
    "USA_ID",
    "Birthdate",
    "ID_Numb",
    "Team",
    "Relay_Rank",
    "Row_Numb.x",
    "Row_Numb.y",
    "as_lines_list_2",
    "First",
    "Last",
    "Last_Name",
    "Finals_Time_sec",
    "New_Place",
    "Finals_Place",
    "DQ",
    "Heat",
    "Heat_Row_Min",
    "Exhibition",
    "Time",
    "Lane",
    "Time_Score_String",
    "Grade_String",
    "Name_String",
    "Row_Fill",
    "Row_Numb_2",
    "minimum_row",
    "maximum_row",
    "Colon_String",
    "old_names",
    "new_names",
    "flag",
    "split_length",
    "split_len",
    "Relay_Swimmer_1",
    "Relay_Swimmer_2",
    "Relay_Swimmer_3",
    "Relay_Swimmer_4",
    "Split_50",
    "Age",
    "Para",
    "typo",
    "replacement",
    "clean",
    "Switch",
    "avoid",
    "Place_1",
    "Min_C_Place",
    "Prelims_Place",
    "First_Name",
    "Name_2",
    "Name_3",
    "where",
    "fFactor",
    "fIncre",
    "Time_Converted_sec",
    "Time_Converted_mmss",
    "split_length_omega",
    "Reaction_Time",
    "Finals_Time_Sec",
    "Split_Total",
    "Indent_Length",
    "Dummy",
    "Split_Distance",
    "Split",
    "split_length_splash",
    "Split_1",
    "Split_2",
    "Split_3",
    "Split_4",
    "Heat_Lane",
    "row_index"
  )
)
